# Undocumented Examples

This directory contains examples that have not been incorporated into the documentation website yet.
They shouldn't be broken (please raise an issue if you notice they are), but they contain limited context or exposition.

## Contents

- **Multirotor Dynamics**: Modeling flight vehicles with rotor aerodynamics, including blade element momentum theory
- **CartPole**: Parameter estimation and trajectory optimization for the classic Cart-Pole control system
- **Subsonic F-16**: Comparison of reference "textbook" code ported from MATLAB/FORTRAN to Archimedes
- **TrajOpt**: Several examples of using the experimental pseudospectral optimal control module.